#! /usr/bin/python
# -*- coding: utf-8 -*-



# import funkcí z jiného adresáře
import sys
import os.path
import io3d
path_to_script = os.path.dirname(os.path.abspath(__file__))
#import featurevector
import unittest

import logging
logger = logging.getLogger(__name__)

# import apdb
# apdb.set_trace();
# import scipy.io
import numpy as np

# ----------------- my scripts --------
import argparse
from . import segmentation_general

class Registration:
    """
    Register all data to first given.
    """
    def __init__(self):
        pass

    def set_params(self):
        pass

    def add_data(self, datap):
        """
        Add
        :param datap: dict with key ["data3d", "voxelsize_mm"].
        datap = {
            "data3d" : np.zeros(10, 15, 15),
            "voxelsize_mm" : [1.1, 0.5, 0.5]
        }
        :return:
        """
        pass

    def run(self):

        pass

    def get_output(self):
        pass



if __name__ == "__main__":

    #logger = logging.getLogger(__name__)
    logger = logging.getLogger()

    logger.setLevel(logging.WARNING)
    ch = logging.StreamHandler()
    logger.addHandler(ch)

    #logger.debug('input params')

    # input parser
    parser = argparse.ArgumentParser(description='Registration data from different files')
    parser.add_argument('-d', '--debug', action='store_true',
            help='run in debug mode')
    parser.add_argument('-i', '--inputfile',  default=None, nargs="N",
            help='input file or directory with data')
    parser.add_argument('-o', '--outpufile',  default=None,
                        help='output file or directory with data')
    args = parser.parse_args()


    if args.debug:
        logger.setLevel(logging.DEBUG)



    for fn in args.inputfile:
        datap = io3d.read(fn)

    # pyed = sed3.sed3(datap['data3d'], contour=datap['segmentation'] == datap['slab']['porta'])
    # pyed.show()

    #pyed = sed3.sed3(data['segmentation'])
    #pyed.show()
    # Uvolneni pameti


    if args.outputfile == None:
        io3d.write(datap_out, args.outpufile)





#! /usr/bin/python
# -*- coding: utf-8 -*-



# import funkcí z jiného adresáře
import sys
import os.path
import io3d
path_to_script = os.path.dirname(os.path.abspath(__file__))
#import featurevector
import unittest

import logging
logger = logging.getLogger(__name__)

# import apdb
# apdb.set_trace();
# import scipy.io
import numpy as np

# ----------------- my scripts --------
import argparse
from . import segmentation_general

class VesselSegmentation:
    def __init__(self):
        pass

    def set_params(self):
        pass

    def run(self):
        pass

    def get_output(self):
        pass



if __name__ == "__main__":

    #logger = logging.getLogger(__name__)
    logger = logging.getLogger()

    logger.setLevel(logging.WARNING)
    ch = logging.StreamHandler()
    logger.addHandler(ch)

    #logger.debug('input params')

    # input parser
    parser = argparse.ArgumentParser(description='Segment vessels from liver')
    parser.add_argument('-dd','--dcmdir',
            default=None,
            help='path to data dir')
    parser.add_argument('-d', '--debug', action='store_true',
            help='run in debug mode')
    parser.add_argument('-i', '--inputfile',  default=None,
            help='input file or directory with data')
    args = parser.parse_args()


    if args.debug:
        logger.setLevel(logging.DEBUG)

    defaultoutputfile =  "vessels.pkl"
    if args.defaultoutputfile:
        args.outputfile = defaultoutputfile

    #else:
    #dcm_read_from_dir('/home/mjirik/data/medical/data_orig/46328096/')
        #data3d, metadata = dcmreaddata.dcm_read_from_dir()
    datap = io3d.read(args.inputfile)

    import sed3
    # pyed = sed3.sed3(oseg.orig_scale_segmentation)
    #pyed.show()
# information about crop
    #cri = oseg.crinfo
    #oseg.data3d = oseg.data3d[cri[0][0]:cri[0][1],cri[1][0]:cri[1][1],cri[2][0]:cri[2][1]]
    #pyed = sed3.sed3(oseg.data3d, contour = oseg.orig_scale_segmentation)

    print('slab', datap['slab'])
    #import ipdb; ipdb.set_trace()  # BREAKPOINT
    #pyed = sed3.sed3(data['data3d'], contour = data['segmentation'])
    #pyed.show()
    #import pdb; pdb.set_trace()

    outputTmp = segmentation_general.vesselSegmentation(
        datap['data3d'],
        segmentation = datap['segmentation'],
        #segmentation = oseg.orig_scale_segmentation,
        threshold = -1,
        inputSigma = 0.15,
        dilationIterations = 2,
        nObj = 1,
        biggestObjects = args.biggest,
#        dataFiltering = True,
        interactivity = True,
        binaryClosingIterations = 2,
        binaryOpeningIterations = 0)


    datap['slab']['none'] = 0
    datap['slab']['liver'] = 1
    datap['slab']['porta'] = 2


    #print np.max(output)
    #import pdb; pdb.set_trace()
    #data = {}
    #data['data3d'] = oseg.data3d
    #data['crinfo'] = oseg.crinfo
    #data['segmentation'] = oseg.segmentation
    datap['segmentation'][output] = datap['slab']['porta']
    #data['slab'] = slab


    pyed = sed3.sed3(datap['data3d'], contour=datap['segmentation'] == datap['slab']['porta'])
    pyed.show()

    #pyed = sed3.sed3(data['segmentation'])
    #pyed.show()
    # Uvolneni pameti


    if args.outputfile == None:
        io3d.write(datap, args.outpufile)





import json
import appdirs
import pathlib
import urllib
import urllib.request
import os.path as op
import sys
import os

# print(op.dirname(os.path.abspath(__file__)))
# print(op.join(op.dirname(os.path.abspath(__file__)), "../../bodynavigation/"))
# sys.path.append(op.join(op.dirname(os.path.abspath(__file__)), "../../bodynavigation/"))
#
# import bodynavigation

appname = "LisaMreImport"
appauthor = "mjirik"
dirs = appdirs.AppDirs(appname=appname, appauthor=appauthor)
fn_config_dir = pathlib.Path(dirs.user_config_dir)
fn_config = fn_config_dir / "config.json"
fn_config_dir.mkdir(exist_ok=True, parents=True)
fn_data_dir = pathlib.Path(dirs.user_data_dir)
fn_data_dir.mkdir(exist_ok=True, parents=True)
fn_data = pathlib.Path(dirs.user_config_dir) / "data.json"

# dir for output files
lisa_data = pathlib.Path("~/lisa_data").expanduser()
lisa_data.mkdir(exist_ok=True, parents=True)

with open(fn_config, 'r') as infile:
    data_config = json.load(infile)

url = data_config["url"]
url_list = url + "list.php"

x = urllib.request.urlopen(url)
text = x.read().decode()
# text_lines = text.split("\n")
text_parsered = [text_line.split(" ") for text_line in text.split("\n")]

filenames = [line[0] for line in text_parsered if len(line) > 2]
dates = [line[1] for line in text_parsered if len(line) > 2]
times = [line[2] for line in text_parsered if len(line) > 2]

# table_data = list(zip(*text_parsered))
table_dict = dict(zip(["filename", "date", "time"], [filenames, dates, times]))

# print(list(table_dict))

# data_out = filenames


# with first run just make the list of actual files
if fn_data.exists():
    with open(fn_data, 'r') as infile:
        filenames_local = json.load(infile)
    # set difference
    autolisa_paths = []
    for filename in list(set(filenames) - set(filenames_local)):
        url_file = url + filename
        fn_local = lisa_data / filename
        if not fn_local.exists():
            print("Downloading from {} to {}".format(url_file, fn_local))
            fn_local2, headers = urllib.request.urlretrieve(url_file, filename=fn_local)
        #fn_local and fn_local2 are probably the same
        autolisa_paths.append(fn_local)

    print("Running Auto-Lisa")
    try:
        from lisa import autolisa
        al = autolisa.AutoLisa()
        al.run_in_paths(autolisa_paths)
    except Exception as e:
        import traceback
        traceback.print_exc()

print(fn_data)
# with open(fn_data, 'w') as outfile:
#     json.dump(filenames, outfile)




# ! /usr/bin/python
# -*- coding: utf-8 -*-

import unittest
import numpy as np
import lisa


class VolumetryEvaluationTest(unittest.TestCase):


    # @unittest.skip("Waiting for implementation")
    def test_compare_volumes(self):
        aa = np.zeros([6,6,6], dtype=np.uint8)
        bb = np.zeros([6,6,6], dtype=np.uint8)

        aa[1:5, 1:5, 1:3] = 1
        bb[1:5, 1:3, 1:5] = 1

        import lisa
        stats = lisa.volumetry_evaluation.compare_volumes(aa, bb, [1,1,1])
        # lisa.volumetry_evaluation.compare_volumes(aa.astype(np.int8), bb.astype(np.int), [1,1,1])
        self.assertEqual(stats["dice"], 0.5)
        self.assertAlmostEqual(stats["jaccard"], 1/3.)
        self.assertAlmostEqual(stats["voe"], 200/3.)  # 66.666666
        # self.assertTrue(False)


#! /usr/bin/python
# -*- coding: utf-8 -*-



# import funkcí z jiného adresáře
import sys
import os.path
import io3d
path_to_script = os.path.dirname(os.path.abspath(__file__))
#import featurevector
import unittest

import logging
logger = logging.getLogger(__name__)

# import apdb
# apdb.set_trace();
# import scipy.io
import numpy as np

# ----------------- my scripts --------
import argparse
from . import segmentation_general

class MultimodalVesselSegmentation:
    def __init__(self):
        pass

    def set_params(self):
        pass

    def run(self):
        pass

    def get_output(self):
        pass



